formattools.get_context_mark_format_pieces
==========================================

.. autofunction:: abjad.tools.formattools.get_context_mark_format_pieces.get_context_mark_format_pieces
   :noindex:
